<?php
/*
 * ショッピングCMS
 * Copyright (c) 2011-2022 by Crytus All rights reserved.
 *
 * 【注意】このファイルの修正は充分ご注意ください。
 * 修正する前には、必ずバックアップを保存してください。
 * 動作がおかしくなったら元のファイルに戻してください。
 * このファイルの漢字コードはHTMLと同じにしてください。
 *
 * SQLite3版 2014/09/16
 * cart動作修正 2014/10/29
 * 管理画面のレスポンシブ化 2016/01/08
 */
ini_set("short_open_tag", "0");
ini_set("magic_quotes_gpc", "0");
ini_set("mbstring.encoding_translation", "0");

// エラー出力の指定
//error_reporting (E_ALL & ~E_NOTICE & ~E_WARNING & ~E_STRICT & ~E_DEPRECATED);
error_reporting (E_ALL & ~E_NOTICE & ~E_WARNING);

// セッションの開始
session_start();

// HTMLとスクリプトの漢字コード（このファイルの漢字コードと一致させてください）
//define("SCRIPT_ENCODING", "SJIS");	// Shift-JISの場合先頭の'//'を取ります。
define("SCRIPT_ENCODING", "UTF-8");	// UTF-8の場合先頭の'//'を取ります。

// データベースの漢字コード
define("DB_ENCODING", "UTF-8");

// メールの漢字コード(UTF-8かJIS)
define("MAIL_ENCODING", "JIS");

// データベースファイルの場所と名前
$DB_URI = "data/shop.sqlite";

// 一覧の1ページあたりの表示件数
define("PAGE_LIMIT", 10);	// 10件

//-------------------------------------------------------------
// 動作環境チェック
if (substr(phpversion(), 0, 1) == "4") {
	error_exit("このシステムはPHP5 が必要です。ご確認をお願い致します。");
}
if (!class_exists("PDO")) {
	error_exit("簡易データベース(SQLite3)が使えません。ご確認をお願い致します。");
} else {
	$ary = PDO::getAvailableDrivers();
	if (!in_array("sqlite", $ary)) {
		error_exit("簡易データベース(SQLite3)が使えません。ご確認をお願い致します。");
	}
}
if (!function_exists("mb_convert_encoding")) {
	error_exit("日本語変換処理が使えません。ご確認をお願い致します。");
}
if (!function_exists("ImageCreateFromString")) {
	error_exit("画像処理が組み込まれていません。ご確認をお願い致します。");
}
if (!file_exists($DB_URI)) {
	error_exit("データファイル（{$DB_URI}）がみつかりません。ご確認をお願い致します。");
}
//-------------------------------------------------------------
// XSS対策
if (is_array($_REQUEST) && (!$_SESSION["LOGIN"])) {
	foreach ($_REQUEST as $k => $v) {
		if (is_array($v)) {
			foreach ($v as $k2 => $v2) {
				$_REQUEST[$k][$k2] = mb_ereg_replace("<.*>", "", $v2);
			}
		} else {
			$_REQUEST[$k] = mb_ereg_replace("<.*>", "", $_REQUEST[$k]);
		}
	}
}
// 設定
$config = array(
	"nologin" => "0",		// 管理画面のログイン(0:ログインできる、1:ログインできない)
	// トップページお知らせ件数
	"info_max" => 10,
);

$pref_list = array(
	"1" => "北海道", 
	"2" => "青森県", 
	"3" => "岩手県", 
	"4" => "宮城県", 
	"5" => "秋田県", 
	"6" => "山形県", 
	"7" => "福島県", 
	"8" => "茨城県", 
	"9" => "栃木県", 
	"10" => "群馬県", 
	"11" => "埼玉県", 
	"12" => "千葉県", 
	"13" => "東京都", 
	"14" => "神奈川県", 
	"15" => "新潟県", 
	"16" => "富山県", 
	"17" => "石川県", 
	"18" => "福井県", 
	"19" => "山梨県", 
	"20" => "長野県", 
	"21" => "岐阜県", 
	"22" => "静岡県", 
	"23" => "愛知県", 
	"24" => "三重県", 
	"25" => "滋賀県", 
	"26" => "京都府", 
	"27" => "大阪府", 
	"28" => "兵庫県", 
	"29" => "奈良県", 
	"30" => "和歌山県", 
	"31" => "鳥取県", 
	"32" => "島根県", 
	"33" => "岡山県", 
	"34" => "広島県", 
	"35" => "山口県", 
	"36" => "徳島県", 
	"37" => "香川県", 
	"38" => "愛媛県", 
	"39" => "高知県", 
	"40" => "福岡県", 
	"41" => "佐賀県", 
	"42" => "長崎県", 
	"43" => "熊本県", 
	"44" => "大分県", 
	"45" => "宮崎県", 
	"46" => "鹿児島県", 
	"47" => "沖縄県", 
);

$script_encoding = SCRIPT_ENCODING;

//-------------------------------------------------------------
include("demo.php");
//
$dbh = new PDO("sqlite:" . $DB_URI);	// 'sqlite:test1.db'

$act = $_REQUEST["act"];
if (!$act) {
	$act = "index";
}

// バイナリー処理のファイル
$binary = array(
	"png",
	"jpg",
	"gif",
);

if ($act == "file") {
	$file = $_REQUEST["f"];
	if ($file) {
		if (file_exists($file)) {
			$contents = file_get_contents($file);
		} else if (file_exists("_files/" . $file)) {
			$contents = file_get_contents("_files/" . $file);
		} else {
			$contents = load_blob($file);
			$ary = explode(".", $file);
			if (count($ary) > 1) {	// 拡張子あり？
				if (in_array($ary[count($ary)-1], $binary)) {
					$contents = base64_decode($contents);
				}
			}
		}
	}
	header('Content-Type: ' . get_mime_types($file));
	echo $contents;
	exit;
}

// --------------------------------
exec_file("sqlite_db.inc");
exec_file("dbaccess.inc");

exec_file("cms.inc");
exec_file("info.inc");
exec_file("info_item.inc");
exec_file("image.inc");
exec_file("orders.inc");

exec_file("htmltemplate.inc");
exec_file("shop_core.php");
// --------------------------------
// 共通設定
$siteinfo = get_setup();
$data["siteinfo"] = $siteinfo;
//
$group = get_group();
$data["group"] = $group;
//
$group_list = array();
foreach ($group as $val) {
	$group_list[$val["id"]] = $val["title"];
}
//
$setup = get_setup();
// 支払方法
$pay_list = array();
for ($i = 1; $i < 6; $i++) {
	if ($setup["pay" . $i]) {
		unset($v);
		$v["id"] = $i;
		$v["title"] = $setup["pay" . $i];
		$v["comment"] = $setup["pay_comment" . $i];
		$pay_list[] = $v;
	}
}
// 配送希望時間
$time_list = array();
for ($i = 1; $i <= 6; $i++) {
	if ($setup["send_time" . $i]) {
		unset($v);
		$v["id"] = $i;
		$v["title"] = $setup["send_time" . $i];
		$time_list[] = $v;
	}
}
// 配送希望日
if ($setup["send_date1"] && $setup["send_date2"]) {
	$send_list = array();
	for ($i = 0; $i < $setup["send_date2"]; $i++) {
		$tm = mktime(0, 0, 0, date('m'), date('d') + $setup["send_date1"] + $i, date('Y'));
		unset($v);
		$v["id"] = date('Y-m-d', $tm);
		$v["title"] = date('m', $tm) . "月" . date('d', $tm) . "日";
		$send_list[] = $v;
	}
}
// --------------------------------
$form_check = array(
	"mode" => array(
		"name" => "",
		"require" => true,
	),
	"name" => array(
		"name" => "お名前",
		"require" => true,
	),
	"kana" => array(
		"name" => "ヨミガナ",
		"require" => true,
	),
	"email" => array(
		"name" => "メールアドレス",
		"require" => true,
		"check" => "email",
	),
	"email2" => array(
		"name" => "メールアドレス(確認)",
		"require" => true,
		"check" => "email",
	),
	"zip" => array(
		"name" => "郵便番号",
		"require" => true,
		"check" => "number",
	),
	"pref" => array(
		"name" => "都道府県",
		"require" => true,
	),
	"address" => array(
		"name" => "住所",
		"require" => true,
	),
	"tel" => array(
		"name" => "電話番号",
		"require" => true,
		"check" => "number",
	),
	"pay" => array(
		"name" => "お支払方法",
		"require" => true,
	),
	"date" => array(
		"name" => "お届け日",
		"require" => false,
	),
	"time" => array(
		"name" => "時間帯指定",
		"require" => false,
	),
	"comment" => array(
		"name" => "ご要望・ご連絡事項",
		"require" => false,
	),
	"to_name" => array(
		"name" => "お届け先お名前",
		"require" => false,
	),
	"to_kana" => array(
		"name" => "お届け先ヨミガナ",
		"require" => false,
	),
	"to_zip" => array(
		"name" => "お届け先郵便番号",
		"require" => false,
		"check" => "number",
	),
	"to_pref" => array(
		"name" => "お届け先都道府県",
		"require" => false,
	),
	"to_address" => array(
		"name" => "お届け先住所",
		"require" => false,
	),
	"to_tel" => array(
		"name" => "お届け先電話番号",
		"require" => false,
		"check" => "number",
	),
);

function get_form($form, $value)
{
	$msg = array();
	$data = array();
	foreach ($form as $key => $val) {
		if (isset($value[$key])) {
			$data[$key] = $value[$key];
			if ($value[$key] == "") {
				if ($val["require"]) {
					$msg[$key] = $val["name"] . "を入力してください";
				}
			} else if ($value[$key] && $val["check"]) {
				if ($val["check"] == "number") {
					if (!mb_ereg("[0-9\-]+", $value[$key])) {
						$msg[$key] = $val["name"] . "は半角数字で入力してください";
					}
				} else if ($val["check"] == "email") {
					if (!mb_ereg("[a-zA-Z0-9_.\-]+@[a-zA-Z0-9_.\-]+", $value[$key])){
						$msg[$key] = $val["name"] . "に誤りがあります";
					}
				}
			}
		}
	}
	return array($data, $msg);
}

// --------------------------------
// カート表示
if ($_SESSION["CART"]) {
	$data["cart_total"] = number_format($_SESSION["CART"]["total"]);
	$data["cart_count"] = count($_SESSION["CART"]["items"]);
} else {
	$data["cart_total"] = "0";
	$data["cart_count"] = "0";
}
// --------------------------------
if (($act == "list")||($act == "search")) {	// 物件一覧
	$page = $_REQUEST["page"];
	if (!$page) {
		$page = 1;
	}
	$ord = $_REQUEST["ord"];
	if (!$ord) {
		$ord = "";
	}
	$kind = $_REQUEST["kind"];
	if (!$kind) {
	//	$kind = "1";
	}
	$top = $_REQUEST["top"];
	if (!$top) {
		$top = "0";
	}
	$limit = $_REQUEST["limit"];
	if (!$limit) {
		$limit = PAGE_LIMIT;
	}
	//$html = $_REQUEST["html"];
	//
	$keyword = $_REQUEST["keyword"];
	$form["keyword"] = $keyword;
	$form["ord"] = $ord;
	$form["kind"] = $kind;
	//
	$propaty = get_item_propaty($kind);
	// 項目検索
	$search = array();
	for ($i = 1; $i <= 10; $i++) {
		if (isset($_REQUEST["info" . $i])) {
			$v = trim($_REQUEST["info" . $i]);
			if ($v) {
				$search["info" . $i] = $v;
				$form["info" . $i] = $v;
			}
		}
	}
	$data["form"] = $form;
	//
	$data["title"] = $propaty["item_title"];
	$data["contents"] = $propaty["item_contents"];
	list($list, $pager) = item_list($kind, $ord, $page, $limit, $top, $search, $keyword);
	$data["list"] = $list;
	$data["pager"] = $pager;
	if ($pager) {
		$data["total"] = $pager["total"];
	} else {
		$data["total"] = count($list);
	}
	$data["order"] = $ord;
	$data["ord" . $ord] = "1";
	$data["kind"] = $kind;
	$data["limit"] = $limit;
	$data["html"] = $html;
	$data["top"] = $top;
	//
	if (!$html) {
		$html = $propaty["list_html"];
	}
	$data["ranking"] = get_ranking(5);	// 人気5件
	$data["osusume"] = item_list(0, 0, 0, 5, 2);	//●●●全ページにおすすめを表示させる。この行と15行ぐらい下の２か所。
	$html = filecheck($html);
	htmltemplate::t_include($html, $data);
	exit;
}
// --------------------------------
// 詳細
if ($act == "item") {
	$id = $_REQUEST["id"];
	if ($id) {
		// 物件
		$item = get_item($id);
		$data["item"] = $item;
		//
		$data["ranking"] = get_ranking(5);	// 人気5件
		$data["osusume"] = item_list(0, 0, 0, 5, 2);	//●●●全ページにおすすめを表示させる。この行と15行ぐらい上の２か所。
		htmltemplate::t_include($item["propaty"]["item_html"], $data);
		exit;
	}
}
// --------------------------------
// カート
if ($act == "cart") {
	if ($_REQUEST["mode"] == "add") {	// 追加
		$id = $_REQUEST["id"];
		$qty = $_REQUEST["qty"];
		$item = get_item($id);
		if ($item) {
			$items = array();
			foreach ($_SESSION["CART"]["items"] as $val) {
				if ($val["id"] != $id) {
					$items[] = $val;
				} else {
					if ($qty) {
						// 同じ商品は合算しないで後の数量が有効
						$val["qty"] = $qty;
						$val["total"] = $val["price"] * $qty;
						$items[] = $val;
						$qty = 0;
					}
				}
			}
			if ($qty) {
				unset($v);
				$v["id"] = $id;
				$v["title"] = $item["title"];
				$v["price"] = $item["price"];
				$v["image"] = $item["image1_file"];
				$v["qty"] = $qty;
				$v["total"] = $item["price"] * $qty;
				array_push($items, $v);
			}
			if (count($items)) {
				$_SESSION["CART"]["items"] = $items;
			} else {
				unset($_SESSION["CART"]["items"]);
			}
			header("location: ./?act=cart");
			exit;
		} else {
			$data["message"] = "選択した商品はありません。";
		}
	}
	if ($_REQUEST["mode"] == "clear") {	// 空に
		unset($_SESSION["CART"]);
	}
	if ($_REQUEST["mode"] == "del") {	// 削除
		$id = $_REQUEST["id"];
		$item = get_item($id);
		if ($item) {
			$items = array();
			foreach ($_SESSION["CART"]["items"] as $val) {
				if ($val["id"] != $id) {
					$items[] = $val;
				}
			}
			if (count($items)) {
				$_SESSION["CART"]["items"] = $items;
			} else {
				unset($_SESSION["CART"]["items"]);
			}
		} else {
			$data["message"] = "選択した商品はありません。";
		}
	}
	if ($_REQUEST["mode"] == "change") {	// 数量変更
		$id = $_REQUEST["id"];
		$qty = $_REQUEST["qty"];
		$item = get_item($id);
		if ($item) {
			$items = array();
			foreach ($_SESSION["CART"]["items"] as $val) {
				if ($val["id"] == $id) {
					$val["qty"] = $qty;
					$val["total"] = $item["price"] * $qty;
				}
				$items[] = $val;
			}
			if (count($items)) {
				$_SESSION["CART"]["items"] = $items;
			} else {
				unset($_SESSION["CART"]["items"]);
			}
		} else {
			$data["message"] = "選択した商品はありません。";
		}
	}
	if ($_SESSION["CART"]["items"]) {
		// 合計、送料計算
		$total = 0;
		$send = 0;
		$total_qty = 0;
		$items = array();
		foreach ($_SESSION["CART"]["items"] as $val) {
			$val["qty" . $val["qty"] . "_sel"] = "selected";
			$val["price_s"] = number_format($val["price"]);
			$val["total_s"] = number_format($val["total"]);
			$items[] = $val;
			$total += $val["total"];
			$total_qty += $val["qty"];
		}
		$data["items"] = $items;
		// 送料計算
		if ($setup["sendtype"] == "1") {	// 無料
			$data["send_s"] = "無料";
		} else if ($setup["sendtype"] == "2") {	// 一律
			if ($setup["sendlimit"]) {
				if ($total < $setup["sendlimit"]) {
					$send = $setup["sendfee"];
				}
			} else {
				$send = $setup["sendfee"];
			}
			$data["send_s"] = number_format($send) . "円";
		} else if ($setup["sendtype"] == "3") {	// 個数分
			if ($setup["sendlimit"]) {
				if ($total < $setup["sendlimit"]) {
					$send = $setup["sendfee"] * $total_qty;
				}
			} else {
				$send = $setup["sendfee"] * count($items);
			}
			$data["send_s"] = number_format($send) . "円";
		} else if ($setup["sendtype"] == "4") {	// 別途お知らせ
			$data["send_s"] = "別途お知らせ";
		} else if ($setup["sendtype"] == "5") {	// 送料着払い
			$data["send_s"] = "送料着払い";
		}
		//
		$_SESSION["CART"]["total"] = $total;
		$_SESSION["CART"]["send"] = $send;
		$_SESSION["CART"]["send_s"] = $data["send_s"];
		$data["total_s"] = number_format($total);
		$data["alltotal_s"] = number_format($total + $send);
	} else {
		unset($_SESSION["CART"]);
		if (!$data["message"]) {
			$data["message"] = "ショッピングカートは空です。";
		}
	}
	//
	htmltemplate::t_include("cart.html", $data);
	exit;
}
if ($act == "cart1") {
	//
	if (!$_SESSION["CART"]["items"]) {
		$data["message"] = "ショッピングカートは空です。";
		htmltemplate::t_include("cart.html", $data);
		exit;
	}
	unset($_SESSION["FORM"]);
	$data["pay_list"] = $pay_list;
	if ($time_list) {
		$data["time_list"] = $time_list;
		$data["send_request"] = "1";
	}
	if ($send_list) {
		$data["send_list"] = $send_list;
		$data["send_request"] = "1";
	}
	htmltemplate::t_include("cart1.html", $data);
	exit;
}
if (($act == "cart2")||($act == "cart1_reinput")) {
	if ($act == "cart1_reinput") {
		$form = $_SESSION["FORM"];
		unset($_SESSION["FORM"]);
		$msg = array();
	} else {
		list($form, $msg) = get_form($form_check, $_REQUEST);
	}
	if ($form) {
		if ($form["to_pref"] || $form["to_zip"] || $form["to_address"] || $form["to_name"] || $form["to_kana"]) {
			if ($form["to_pref"] && $form["to_zip"] && $form["to_address"] && $form["to_name"] && $form["to_kana"]) {
				//
			} else {
				$msg["to_name"] = "お届け先を指定する場合は、全て記入してください。";
			}
		}
		if ($form["email"] && $form["email2"]) {
			if ($form["email"] != $form["email2"]) {
				$msg["email"] = "メールアドレスが一致していません。";
			}
		}
		if ($msg || ($act == "cart1_reinput")) {
			$data["message"] = join("<br>", $msg);
			$data["form"] = $form;
			if ($form["pref"]) {
				$data["pref" . $form["pref"]] = "selected";
			}
			if ($form["to_pref"]) {
				$data["to_pref" . $form["to_pref"]] = "selected";
			}
			if ($form["date"]) {
				foreach ($send_list as $key => $val) {
					if ($form["date"] == $val["id"]) {
						$send_list[$key]["sel"] = "selected";
					}
				}
			}
			if ($send_list) {
				$data["send_list"] = $send_list;
				$data["send_request"] = "1";
			}
			if ($form["day"]) {
				$data["day" . $form["day"]] = "selected";
			}
			if ($form["pay"]) {
				$data["pay" . $form["pay"]] = "selected";
			}
			if ($form["time"]) {
				$data["time" . $form["time"]] = "selected";
			}
			if ($form["pay"]) {
				foreach ($pay_list as $key => $val) {
					if ($form["pay"] == $val["id"]) {
						$pay_list[$key]["sel"] = "selected";
					}
				}
			}
			$data["pay_list"] = $pay_list;
			if ($form["time"]) {
				foreach ($time_list as $key => $val) {
					if ($form["time"] == $val["id"]) {
						$time_list[$key]["sel"] = "selected";
					}
				}
			}
			if ($time_list) {
				$data["time_list"] = $time_list;
				$data["send_request"] = "1";
			}
			htmltemplate::t_include("cart1.html", $data);
			exit;
		} else {
			$_SESSION["FORM"] = $form;
			//
			$form["pref"] = $pref_list[$form["pref"]];
			$form["to_pref"] = $pref_list[$form["to_pref"]];
			if (isset($form["pay"])) {
				foreach ($pay_list as $val) {
					if ($val["id"] == $form["pay"]) {
						$form["pay"] = $val["title"];
						break;
					}
				}
			}
			if (isset($form["time"])) {
				foreach ($time_list as $val) {
					if ($val["id"] == $form["time"]) {
						$form["time"] = $val["title"];
						break;
					}
				}
				if ($form["time"] == "") {
					$form["time"] = "";
				}
			}
			if (isset($form["date"])) {
				foreach ($send_list as $val) {
					if ($val["id"] == $form["date"]) {
						$form["date"] = $val["title"];
						break;
					}
				}
				if ($form["date"] == "") {
					$form["date"] = "準備出来しだい";
				}
			}
			$data["form"] = $form;
			//
			htmltemplate::t_include("cart2.html", $data);
			exit;
		}
	}
}
if ($act == "cart3") {
	if ($_SESSION["FORM"] && $_SESSION["CART"]) {
		$form = $_SESSION["FORM"];
		unset($_SESSION["FORM"]);
		$cart = $_SESSION["CART"];
		unset($_SESSION["CART"]);
		//
		$items = "";
		foreach ($cart["items"] as $key => $val) {
			$items .= $val["id"] . ":" . $val["title"] . ":" . $val["qty"] . ":" . $val["price"] . ":" . $val["total"] . "\n";
			$cart["items"][$key]["price_s"] = number_format($val["price"]);
			$cart["items"][$key]["total_s"] = number_format($val["total"]);
		}
		$cart["send_s"] = number_format($cart["send"]);
		$cart["total_s"] = number_format($cart["send"] + $cart["total"]);
		// 注文保存
		$item["name"] = $form["name"];
		$item["kana"] = $form["kana"];
		$item["email"] = $form["email"];
		$item["zip"] = $form["zip"];
		$item["pref"] = $pref_list[$form["pref"]];
		$item["address"] = $form["address"];
		$item["tel"] = $form["tel"];
		$item["pay"] = $form["pay"];
		$item["send_date"] = $form["date"];
		$item["send_time"] = $form["time"];
		$item["comment"] = $form["comment"];
		$item["to_name"] = $form["to_name"];
		$item["to_kana"] = $form["to_kana"];
		$item["to_zip"] = $form["to_zip"];
		$item["to_pref"] = $pref_list[$form["to_pref"]];
		$item["to_address"] = $form["to_address"];
		$item["to_tel"] = $form["to_tel"];
		$item["send"] = $cart["send"];
		$item["total"] = $cart["total"];
		$item["items"] = $items;
		if (isset($item["pay"])) {
			foreach ($pay_list as $val) {
				if ($val["id"] == $item["pay"]) {
					$item["pay"] = $val["title"];
					$item["pay_comment"] = $val["comment"];
					break;
				}
			}
		}
		if (isset($item["send_time"])) {
			foreach ($time_list as $val) {
				if ($val["id"] == $item["send_time"]) {
					$item["send_time"] = $val["title"];
					break;
				}
			}
		}
		$order_id = Orders::addData($item);
		$item["order_id"] = $order_id;
		$item["date"] = date("Y/m/d");
		// メール送信
		template_mail($form["email"], "subject2", "body2", array("order" => $item, "cart" => $cart), $setup["admin_mail"]);
		//
		htmltemplate::t_include("cart3.html", $data);
		exit;
	}
}
// --------------------------------
if (($act == "toiawase")||($act == "toiawase_reinput")) {
	$id = $_REQUEST["id"];
	$item = get_item($id);
	if ($id && $item) {
		$data["item"] = $item;
		//
		$mode = $_REQUEST["mode"];
		if ($mode == "form") {
			$name = $_REQUEST["name"];
			$email = $_REQUEST["email"];
			$comment = $_REQUEST["comment"];
			$form["name"] = $name;
			$form["email"] = $email;
			$form["comment"] = $comment;
			$data["form"] = $form;
			if ($name && $email && $comment) {
				$data["mode"] = "confirm";
				$data["confirm"] = "1";
				$_SESSION["form"] = $form;
			} else {
				$msg = array();
				if (!$name) {
					$msg[] = $error_msg1;
				}
				if (!$email) {
					$msg[] = $error_msg2;
				}
				if (!$comment) {
					$msg[] = $error_msg3;
				}
				$data["message"] = join("<br/>", $msg);
				$data["mode"] = "form";
			}
		} else if ($mode == "confirm") {
			$form = $_SESSION["form"];
			$body = $mail_body;
			$body = str_replace("{info_id}", $item["info_id"], $body);
			$body = str_replace("{title}", $item["title"], $body);
			$body = str_replace("{name}", $form["name"], $body);
			$body = str_replace("{email}", $form["email"], $body);
			$body = str_replace("{comment}", $form["comment"], $body);
			// メール送信
			$tmp = $pre_admin . "\n" . $body . "\n\n" . $post_admin;
			sendmail2($from_mail, $admin_mail, $subject, $tmp, null, $from_name);
			$tmp = $form["name"] . "{$mail_sama}\n\n{$pre_user}\n{$body}\n\n{$post_user}";
			sendmail2($from_mail, $form["email"], $subject, $tmp, null, $from_name);
		} else {
			$data["mode"] = "form";
		}
		if ($act == "toiawase_reinput") {
			$data["form"] = $_SESSION["form"];
			$data["mode"] = "form";
		}
		$data["ranking"] = get_ranking(5);	// 人気5件
		//
		htmltemplate::t_include("toiawase.html", $data);
		exit;
	}
}
// --------------------------------
// トップページ
$data["osusume"] = item_list(0, 0, 0, 5, 2);	// おすすめ5件
$data["newitem"] = item_list(0, 0, 0, 10, 1);	// 新着10件
$data["ranking"] = get_ranking(5);	// 人気5件
//
//$data["list1"] = item_list(1, 0, 0, 8, 1);	// 種類1、新着8件
//$data["list2"] = item_list(2, 0, 0, 8, 1);	// 種類2、新着8件
//
$data["newinfo"] = get_newinfo(($config["info_max"] == "")?10:$config["info_max"]);
//
$html = "top.html";
if ($act != "index") {
	$html= filecheck($act . ".html");
}
$html= filecheck($html);
htmltemplate::t_include($html, $data);
exit;
// --------------------------------
// 異常終了
function error_exit($msg)
{
	echo '<html><head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"></head><body>';
	echo $msg;
	echo "</body></html>";
	exit;
}
// 仮想ファイルを読み込む
function exec_file($file)
{
	global $config;
	global $DB_URI;
	global $script_encoding;

	if (file_exists("_files/" . $file)) {
		include_once("_files/" . $file);
	} else {
		$php = load_blob($file);
		if ($php) {
	 		eval("?>" . $php);
	 	}
	}
}
// 大きなデータを取り出す
function load_blob($key)
{
	global $dbh;

//echo "load:{$key}<br>";
	$sql = "select seq from file_list where name='{$key}'";
	//$result = sqlite_query($dbh, $sql);
	//$val = sqlite_fetch_all($result);
	$ret = $dbh->query($sql);
	$val = $ret->fetchAll();

	if ($val) {
		$val = $val[0];
		$id = $val["seq"];
		$file = load_db_file($id);
		return $file;
	}
	return false;
}

function load_db_file($id)
{
	global $dbh;

	$data = "";
	$sql = "select contents from file_contents where file_num={$id} order by seq";
	//$result = sqlite_query($dbh, $sql);
	$stmt = $dbh->query($sql);
	while ($ret = $stmt->fetch(PDO::FETCH_ASSOC)) {
//	while ($ret = sqlite_fetch_array($result, SQLITE_ASSOC, TRUE)) {
		$data .= $ret["contents"];
	}
	return $data;
}
// magic_quotes_gpcの対応
function safeStripSlashes($var) {
	if (is_array($var)) {
		return array_map('safeStripSlashes', $var);
	} else {
/*
		if (get_magic_quotes_gpc()) {
			$var = stripslashes($var);
		}
*/
		return $var;
	}
}
// --------------------------------
// お知らせ
function get_newinfo($max=10)
{
	global $DB_URI;

	$sql = "select * from info where open=1 and kind=" . INFO_RSS;
	$inst = DBConnection::getConnection($DB_URI);
	$ret = $inst->search_sql($sql);
	$list = array();
	if ($ret["count"]) {
		foreach ($ret["data"] as $val) {
			$item = get_setup(INFO_RSS, $val["info_id"]);
			if ($item["open"]) {
				$item["reg_date"] = $val["reg_date"];
				if (newflag(-1, $item["rss_date"])) {
					$item["new_flag"] = "1";
				}
				if (!$item["rss_date"]) {
					$item["rss_date"] = $item["reg_date"];
				}
				$t = strtotime($item["rss_date"]);
				while (1) {
					if ($list[$t]) {
						$t++;
					} else {
						$list[$t] = $item;
						break;
					}
				}
			}
		}
	}
	// 並べ替え
	$rss = array();
	if ($list) {
		$count = 0;
		krsort($list);
		foreach ($list as $val) {
			$val["rss_date"] = substr($val["rss_date"], 0, 4) . "/" . substr($val["rss_date"], 5, 2) . "/" . substr($val["rss_date"], 8, 2);
			$rss[] = $val;
			$count++;
			if ($count >= $max) {
				break;
			}
		}
	}
	return $rss;
}
// --------------------------------
// ランキングを得る
function get_ranking($num)
{
	$list = item_list(0, 3, 0, $num, 3);
	if ($list) {
		$num = 1;
		foreach ($list as $key => $val) {
			$list[$key]["num"] = $num++;
			$list[$key]["contents"] = mb_strimwidth($val["contents"], 0, 20, "…", SCRIPT_ENCODING);
		}
	}
	return $list;
}
// --------------------------------
// プロパティ
function get_item_propaty($kind)
{
	global $group;

	$info = array("kind" => $kind);
	foreach ($group as $val) {
		if ($val["id"] == $kind) {
			foreach ($val as $key => $val2) {
				if (substr($key, 0, 4) == "info") {
					$info[$key] = $val[$key];
				}
				if (($key == "list_html")||($key == "item_html")) {
					$info[$key] = $val[$key];
				}
			}
			$info["item_title"] = $val["title"];
			$info["item_contents"] = $val["contents"];
			break;
		}
	}
	if (!$info["list_html"]) {
		$info["list_html"] = "list.html";
	}
	if (!$info["item_html"]) {
		$info["item_html"] = "item.html";
	}
	return $info;
}
// --------------------------------
// 一覧取得
function item_list($kind=0, $ord=0, $page=0, $limit=0, $top=0, $search=array(), $keyword="")
{
	global $DB_URI;

	$inst = DBConnection::getConnection($DB_URI);
	$join = "";
	$where = "";
	if ($kind) {
		$k = INFO_ITEM + intval($kind);
		$where = "and info.kind={$k}";
		// プロパティ
		$propaty = get_item_propaty($kind);
	}
	// トップページ用一覧
	if ($top) {
		if ($top == 1) {	// new
			$join = " left join info_item i2 on info.info_id=i2.info_id";
			$where .= " and i2.kind='new' and i2.value=1";
		}
		if ($top == 2) {	// オススメ
			$join = " left join info_item i2 on info.info_id=i2.info_id";
			$where .= " and i2.kind='recommend' and i2.value=1";
		}
	}
	if ($ord == 3) {	// ランキング
		$join = " left join info_item i4 on info.info_id=i4.info_id";
		$where .= " and i4.kind='ranking'";
	}
	if ($keyword) {
		$keyword = mb_convert_encoding($keyword, INTERNAL_ENCODING, SCRIPT_ENCODING);
		$join .= " left join info_item key1 on info.info_id=key1.info_id";
		$where .= " and ((key1.value like '%{$keyword}%' and key1.kind='title') or (key1.value like '%{$keyword}%' and key1.kind='contents')) ";
	}
	// 条件検索
	if ($search) {
		$no = 11;
		foreach ($search as $key => $val) {
			$val = mb_convert_encoding($val, INTERNAL_ENCODING, SCRIPT_ENCODING);
			$join .= " left join info_item i$no on info.info_id=i$no.info_id";
			$where .= " and i$no.value like '%{$val}%' and i$no.kind='$key'";
			$no++;
		}
	}
	//
	$sql = " from info" .
		" left join info_item i1 on info.info_id=i1.info_id " .
		" left join info_item i3 on info.info_id=i3.info_id {$join}" .
		" where info.open=1 and i1.kind='price' and i3.kind='zaiko' {$where}";
	if ($page && $limit) {
		$ret = $inst->search_sql("select count(info.info_id) as num" . $sql);
		$count = $ret["data"][0]["num"];
		$pages = intval(($count + $limit - 1) / $limit);
		$pager = array();
		if ($pages > 1) {
			$pager = page_index($page, $pages);
			$pager["total"] = $count;
		}
	}
	$sql .= " group by info.info_id";
	if ($ord == 1) {
		$sql .= " order by price desc";	// 高い順
	} else if ($ord == 2) {
		$sql .= " order by price";	// 安い順
	} else if ($ord == 3) {
		$sql .= " order by (i4.value+0) desc";	// 人気ランキング順
	} else {
		$sql .= " order by info.reg_date desc";	// 新着
	}
	if ($page && $limit) {
		$p["offset"] = ($page - 1) * $limit;
		$p["limit"] = $limit;
	} else {
		$p["offset"] = 0;
		$p["limit"] = $limit;
	}
	$ret = $inst->search_sql("select info.info_id as info_id,i1.value+0 as price" . $sql, false, $p);
	$list = array();
	if ($ret["count"]) {
		foreach ($ret["data"] as $val) {
			$list[] = get_item($val["info_id"], $propaty);
		}
	}
	if ($page && $limit) {
		return array($list, $pager);
	}
	return $list;
}
// --------------------------------
// 詳細取得
function get_item($info_id, $propaty=null)
{
	$ret = get_infoitem($info_id);
	if (!$ret) return array();
	$info = Info::getData($info_id);
	$kind = $info["kind"] - 100;
	if (!$propaty) {
		// プロパティ
		$propaty = get_item_propaty($kind);
	}
	//
	$list = array("info_id" => $info_id, "kind" => $kind, "propaty" => $propaty);
	$list_item = array();
	$info = array();
	$subitem = array();
	foreach ($ret as $key => $val) {
		if ($propaty[$key]) {
			unset($item);
			if ($val) {
				$item["title"] = $propaty[$key];
				$item["value"] = $val;
				$list[$key] = $item;
				if (substr($key, 0, 4) == "info") {
					$info[] = $item;
				}
			}
		} else if ($val) {
			if (($key == "new") && $val) {
				$list["new_flag"] = $val;
			}
			if (($key == "recommend") && $val) {
				$list["recommend" . $val] = "1";
			}
			if (($key == "zaiko") && $val) {
				$list["zaiko" . $val] = "1";
			}
			$list[$key] = $val;
			if ($key == "price") {
				$list[$key . "_s"] = number_format($val);
			}
		}
		if (substr($key, 0, 5) == "image") {
			if ($val) {
				$img = Image::getData($val);
				if ($img) {
					$list[$key . "_file"] = $img["save_name"];
				}
			}
		}
		if (substr($key, 0, 4) == "item") {
			if ($val) {
				$item = get_infoitem($val);
				if ($item) {
					$img = Image::getData($item["image1"]);
					if ($img) {
						$item["image_file"] = $img["save_name"];
					}
					$item["id"] = $val;
					$subitem[] = $item;
				}
			}
		}
	}
	$list["info"] = $info;	// 詳細用情報
	$list["item"] = $subitem;	// 関連商品
	return $list;
}
// --------------------------------
function template_mail($to, $subject, $body, $data, $to_admin="")
{
	global $setup;

	$body_text = htmltemplate::buffer($setup[$body], $data);
	sendmail2($setup["from_mail"], $to, $setup[$subject], $body_text, null, $setup["from_name"]);
	if ($to_admin) {	// 管理者へ同じメールを送る
		sendmail2($setup["from_mail"], $to_admin, $setup[$subject], $body_text, null, $setup["from_name"]);
	}
}
//
function set_row($ary, $cnt)
{
	$num = 0;
	$col = 0;
	$data = array();
	$row = array();
	foreach ($ary as $val) {
		$row[] = $val;
		if (++$col == $cnt) {
			$data[$num]["num"] = $num + 1;
			$data[$num++]["row"] = $row;
			$row = array();
			$col = 0;
		}
	}
	if ($row) {
		$data[$num]["num"] = $num + 1;
		$data[$num++]["row"] = $row;
	}
	return $data;
}
function newflag($new, $date)
{
	if (defined("NEW_DAYS") && NEW_DAYS) {
		$t = intval((time() - strtotime($date)) / 86400);
		if ($new < 0) {
			if ($t < NEW_DAYS) return 1;
		} else if (defined("NEW_OR")) {
			// OR(新着または設定日数以内の場合)
			if ($new || ($t < NEW_DAYS)) return 1;
		} else if (defined("NEW_AND")) {
			// AND(新着かつ設定日数以内の場合)
			if ($new && ($t < NEW_DAYS)) return 1;
		} else {
			// 自動判定のみ
			if ($t < NEW_DAYS) return 1;
		}
	} else {
		// 新着設定のみ
		if ($new > 0) return 1;
	}
	return 0;
}
// ページャ作成
function page_index($cur, $pages)
{
	$page = array();
	$no = 0;
	if ($cur > 1) {
		$page['prev'] = array('no' => $cur - 1, 'name' => 'PREV', 'link' => 1);
	}
	for ($i = 1; $i <= $pages; $i++) {
		if ($i == $cur) {
			$page['list'][$no] = array('no' => $i, 'name' => $i);
		} else {
			$page['list'][$no] = array('no' => $i, 'name' => $i, 'link' => 1);
		}
		$no++;
	}
	if ($cur < ($pages)) {
		$page['next'] = array('no' => $cur + 1, 'name' => 'NEXT', 'link' => 1);
	}
	return $page;
}
// ------------------------------------
function load_file($f)
{
	$v = file_get_contents($f);

	header('Content-Type: ' . get_mime_types($f));
	echo $v;
	exit;
}

// ファイルの拡張子からMIMEタイプを得る
function get_mime_types($file)
{
	$mime_types = array(
		'txt' => 'text/plain',
		'htm' => 'text/html',
		'html' => 'text/html',
		'php' => 'text/html',
		'css' => 'text/css',
		'js' => 'application/javascript',
		'json' => 'application/json',
		'xml' => 'application/xml',
		'swf' => 'application/x-shockwave-flash',
		'flv' => 'video/x-flv',

		// images
		'png' => 'image/png',
		'jpe' => 'image/jpeg',
		'jpeg' => 'image/jpeg',
		'jpg' => 'image/jpeg',
		'gif' => 'image/gif',
		'bmp' => 'image/bmp',
		'ico' => 'image/vnd.microsoft.icon',
		'tiff' => 'image/tiff',
		'tif' => 'image/tiff',
		'svg' => 'image/svg+xml',
		'svgz' => 'image/svg+xml',

		// archives
		'zip' => 'application/zip',
		'rar' => 'application/x-rar-compressed',
		'exe' => 'application/x-msdownload',
		'msi' => 'application/x-msdownload',
		'cab' => 'application/vnd.ms-cab-compressed',

		// audio/video
		'mp3' => 'audio/mpeg',
		'qt' => 'video/quicktime',
		'mov' => 'video/quicktime',

		// adobe
		'pdf' => 'application/pdf',
		'psd' => 'image/vnd.adobe.photoshop',
		'ai' => 'application/postscript',
		'eps' => 'application/postscript',
		'ps' => 'application/postscript',

		// ms office
		'doc' => 'application/msword',
		'rtf' => 'application/rtf',
		'xls' => 'application/vnd.ms-excel',
		'ppt' => 'application/vnd.ms-powerpoint',

		// open office
		'odt' => 'application/vnd.oasis.opendocument.text',
		'ods' => 'application/vnd.oasis.opendocument.spreadsheet',
	);

	$ary = explode(".", $file);
	if (count($ary) > 1) {	// 拡張子あり？
		if ($mime_types[$ary[count($ary)-1]]) {
			return $mime_types[$ary[count($ary)-1]];
		}
	}
	return "application/octet-stream";	// 不明なファイル
}
function filecheck($html, $default = "top.html")
{
	if (file_exists($html)) {
		return $html;
	}
	if (file_exists("./templates/" . $html)) {
		return $html;
	}
	return $default;
}
